==> PathOfBuildingCommunity-Portable-2.7.0.zip: Data/Uniques/quiver.lua <==
﻿-- Item data (c) Grinding Gear Games

return {
-- Quiver
[[
Asphyxia's Wrath
Two-Point Arrow Quiver
Variant: Pre 3.0.0
Variant: Current
Requires Level 10
Implicits: 1
(20-30)% increased Accuracy Rating
{variant:2}Grants level 5 Frostbite Skill
(8-12)% increased Attack Speed
+(30-40)% to Cold Resistance
(30-40)% increased Chill Duration on Enemies
Gain 20% of Physical Damage as Extra Cold Damage
(7-10)% chance to Freeze
{variant:1}40% reduced Area of Effect of Hex Skills
Hexes on Slain Enemies are transferred to a nearby Enemy
]],[[
Blackgleam
Fire Arrow Quiver
Upgrade: Upgrades to unique{The Signal Fire} via prophecy{Fire and Brimstone}
Variant: Pre 2.0.0
Variant: Current
Requires Level 22
Implicits: 1
Adds 4 to 8 Fire Damage to Attacks with Bows
10% increased Attack Speed
+(80-100) to Evasion Rating
+(10-30) to maximum Mana
{variant:1}(30-50)% of Physical Damage Converted to Fire Damage
{variant:2}50% of Physical Damage Converted to Fire Damage
Adds 5 to 10 Fire Damage to Attacks with Bows
]],[[
The Signal Fire
Fire Arrow Quiver
Variant: Pre 3.14.0
Variant: Current
Source: Upgraded from unique{Blackgleam} using prophecy{Fire and Brimstone}
Requires Level 24
Implicits: 1
Adds 4 to 8 Fire Damage to Attacks with Bows
10% increased Attack Speed
+(80-100) to Evasion Rating
+(10-30) to maximum Mana
{variant:1}Gain (25-35)% of Physical Damage as Extra Fire Damage
{variant:2}Gain (25-35)% of Physical Attack Damage as Extra Fire Damage
50% of Physical Damage Converted to Fire Damage
Adds 5 to 10 Fire Damage to Attacks with Bows
]],[[
Craghead
Serrated Arrow Quiver
Upgrade: Upgrades to unique{Cragfall} via prophecy{Heavy Blows}
Requires Level 5
Implicits: 1
Adds 1 to 4 Physical Damage to Attacks with Bows
(20-25)% reduced Enemy Stun Threshold
25% reduced Projectile Speed
(60-80)% increased Stun Duration on Enemies
Adds 6 to 10 Physical Damage to Attacks with Bows
]],[[
Cragfall
Serrated Arrow Quiver
Source: Upgraded from unique{Craghead} using prophecy{Heavy Blows}
Requires Level 5
Implicits: 1
Adds 1 to 4 Physical Damage to Attacks with Bows
(20-25)% reduced Enemy Stun Threshold
25% reduced Projectile Speed
(60-80)% increased Stun Duration on Enemies
Adds 6 to 10 Physical Damage to Attacks with Bows
50% chance to double Stun Duration
]],[[
Drillneck
Penetrating Arrow Quiver
Requires Level 36
Implicits: 1
Arrows Pierce an additional Target
(8-12)% increased Attack Speed
+350 to Evasion Rating
+(40-50) to maximum Life
Adds (10-14) to (19-24) Physical Damage to Attacks with Bows
Arrows deal 50% increased Damage with Hits and Ailments to Targets they Pierce
]],[[
The Fracturing Spinner
Blunt Arrow Quiver
League: Harbinger
Upgrade: Upgrades to unique{The Shattered Divinity} via currency{Fragmentation Scroll}
Requires Level 60
Implicits: 1
(25-35)% increased Stun Duration on Enemies
Grants Summon Harbinger of Directions Skill
+(30-50) to Strength and Dexterity
Adds (19-22) to (30-35) Fire Damage to Spells and Attacks
Adds (19-22) to (30-35) Cold Damage to Spells and Attacks
+(15-25)% to Fire and Cold Resistances
]],[[
The Shattered Divinity
Blunt Arrow Quiver
League: Harvest
Source: Upgraded from unique{The Fracturing Spinner} via currency{Fragmentation Scroll}
Requires Level 60
Implicits: 1
(25-35)% increased Stun Duration on Enemies
Grants Summon Greater Harbinger of Directions Skill
+(30-50) to Strength and Dexterity
Adds (19-22) to (30-35) Fire Damage to Spells and Attacks
Adds (19-22) to (30-35) Cold Damage to Spells and Attacks
+(15-25)% to Fire and Cold Resistances
]],[[
Hyrri's Bite
Sharktooth Arrow Quiver
Upgrade: Upgrades to unique{Hyrri's Demise} via prophecy{A Dishonourable Death}
Variant: Pre 2.6.0
Variant: Current
Requires Level 10
Implicits: 1
+(3-4) Life gained for each Enemy hit by your Attacks
+(15-25) to Strength
+(35-45) to Dexterity
+(15-25) to Intelligence
{variant:2}Adds 10 to 20 Cold Damage to Attacks
(7-10)% increased Attack Speed
+(2-3) Life gained for each Enemy hit by your Attacks
10% increased Area of Effect of Area Skills
]],[[
Hyrri's Demise
Sharktooth Arrow Quiver
Source: Upgraded from unique{Hyrri's Bite} via prophecy{A Dishonourable Death}
Requires Level 45
Implicits: 1
+(3-4) Life gained for each Enemy hit by your Attacks
+(15-30) to all Attributes
(7-10)% increased Attack Speed
+(2-3) Life gained for each Enemy hit by your Attacks
10% increased Area of Effect
Adds 1 to 2 Cold Damage to Attacks per 10 Dexterity
Adds 1 to 2 Fire Damage to Attacks per 10 Strength
Adds 0 to 3 Lightning Damage to Attacks per 10 Intelligence
]],[[
Maloney's Mechanism
Ornate Quiver
Requires Level 45
Implicits: 1
Has 1 Socket
Has 2 Sockets
Trigger a Socketed Bow Skill when you Attack with a Bow, with a 1 second Cooldown
(7-12)% increased Attack Speed
+(50-70) to maximum Life
5% chance to Blind Enemies on Hit with Attacks
]],[[
Replica Maloney's Mechanism
Ornate Quiver
League: Heist
Requires Level 45
Implicits: 1
Has 1 Socket
Has 2 Sockets
Trigger a Socketed Bow Skill when you Cast a Spell while wielding a Bow
(7-12)% increased Cast Speed
+(50-70) to maximum Life
5% chance to Blind Enemies on Hit with Attacks
]],[[
Maloney's Nightfall
Blunt Arrow Quiver
Variant: Pre 2.6.0
Variant: Current
Requires Level 55
Implicits: 1
(25-35)% increased Stun Duration on Enemies
{variant:1}(8-10)% increased Attack Speed
{variant:2}10% increased Attack Speed
+(50-70) to maximum Life
+(12-16)% to Chaos Resistance
{variant:1}Adds (5-7) to (8-10) Physical Damage to Attacks with Bows
{variant:2}Adds (8-10) to (14-16) Physical Damage to Attacks with Bows
{variant:1}10% chance to create a Smoke Cloud when Hit
{variant:2}25% chance to create a Smoke Cloud when Hit
{variant:1}(20-40)% increased Damage with Hits and Ailments against Blinded Enemies
{variant:2}(40-60)% increased Damage with Hits and Ailments against Blinded Enemies
]],[[
Rearguard
Broadhead Arrow Quiver
Requires Level 28
Implicits: 1
Adds 6 to 12 Physical Damage to Attacks with Bows
+(400-450) to Armour
(20-30)% increased Projectile Speed
50% increased Stun Recovery
(15-20)% increased Projectile Damage
(20-24)% Chance to Block
(12-15)% Chance to Block Spells
]],[[
Rigwald's Quills
Two-Point Arrow Quiver
Variant: Pre 3.14.0
Variant: Current
League: Talisman Standard, Talisman Hardcore
Source: Drops from unique{Rigwald, The Wolven King} (Level 70+)
Requires Level 56
Implicits: 1
(20-30)% increased Accuracy Rating
−10% to Fire Resistance
+(20-30)% to Lightning Resistance
+7 Life gained for each Enemy hit by your Attacks
20% reduced Projectile Speed
(30-50)% increased Projectile Damage
{variant:1}Projectiles Fork
{variant:2}Arrows Fork
]],[[
Saemus' Gift
Spike-Point Arrow Quiver
Requires Level 45
Implicits: 1
(20-30)% increased Global Critical Strike Chance
+(30-40) to Dexterity
(8-12)% increased Cast Speed
+(30-60) to maximum Life
+(20-40)% to Lightning Resistance
20% chance to Avoid being Stunned
1% increased Lightning Damage per 10 Intelligence
]],[[
Scorpion's Call
Broadhead Arrow Quiver
League: Harvest
Requires Level 57
Implicits: 1
Adds 6 to 12 Physical Damage to Bow Attacks
+(20-40) to Dexterity
(150-200) Life Regenerated per Second while in Blood Stance
(40-60)% increased Projectile Damage while in Blood Stance
+(700-1000) to Evasion Rating while in Sand Stance
(20-30)% increased Area of Effect while in Sand Stance
(20-30)% increased Attack Speed if you've changed Stance Recently
]],[[
Skirmish
Two-Point Arrow Quiver
Requires Level 19
Implicits: 1
(20-30)% increased Accuracy Rating
+(15-25) to Intelligence
+(30-50) to maximum Mana
(20-30)% increased Mana Regeneration Rate
0.2% of Physical Attack Damage Leeched as Mana
Attack skills can have 1 additional Totem Summoned at a time
]],[[
Steelworm
Broadhead Arrow Quiver
Requires Level 52
Implicits: 1
6 to 12 Added Physical Damage with Bow Attacks
Grants Call of Steel
(30-60)% increased Evasion Rating and Armour
Deal no Non-Physical Damage
Attacks that Fire Projectiles Consume up to 1 additional Steel Shard
Skills Fire 3 additional Projectiles for 4 seconds after you consume a total of 12 Steel Shards
]],[[
Soul Strike
Spike-Point Arrow Quiver
Variant: Pre 2.5.0
Variant: Current
Requires Level 64
Implicits: 1
(20-30)% increased Global Critical Strike Chance
+30 to Dexterity
Adds (13-18) to (26-32) Chaos Damage to Attacks
(8-12)% increased Attack Speed
+(100-120) to maximum Energy Shield
40% reduced Energy Shield Recharge Rate
{variant:1}150% faster start of Energy Shield Recharge
{variant:2}80% faster start of Energy Shield Recharge
]],[[
Replica Soul Strike
Spike-Point Arrow Quiver
League: Heist
Requires Level 64
Implicits: 1
(20-30)% increased Global Critical Strike Chance
+30 to Dexterity
Adds (13-18) to (26-32) Physical Damage to Attacks
(8-12)% increased Attack Speed
+(60-80) to maximum Life
80% reduced Maximum Recovery per Life Leech
40% increased Maximum total Recovery per second from Life Leech
]],[[
Voidfletcher
Penetrating Arrow Quiver
Elder
Source: Drops from unique{The Elder} (Uber)
Requires Level 68
Implicits: 1
Arrows Pierce an additional Target
Consumes a Void Charge to Trigger Level 20 Void Shot when you fire Arrows
Adds (30-40) to (80-100) Cold Damage to Attacks
+(80-120) to maximum Energy Shield
+(20-30)% to Cold Resistance
+(20-40) Mana gained on Kill
30% increased Projectile Speed
5 Maximum Void Charges
Gain a Void Charge every 0.5 seconds
Elder Item
]],
}

==> PathOfBuildingCommunity-Portable-2.14.0.zip: Data/Uniques/quiver.lua <==
﻿-- Item data (c) Grinding Gear Games

return {
-- Quiver
[[
Asphyxia's Wrath
Two-Point Arrow Quiver
Variant: Pre 3.0.0
Variant: Pre 3.17.0
Requires Level 36
Implicits: 1
(20-30)% increased Global Accuracy Rating
{variant:2}Grants level 5 Frostbite Skill
(8-12)% increased Attack Speed
+(30-40)% to Cold Resistance
(30-40)% increased Chill Duration on Enemies
Gain 20% of Physical Damage as Extra Cold Damage
(7-10)% chance to Freeze
{variant:1}40% reduced Area of Effect of Hex Skills
Hexes on Slain Enemies are transferred to a nearby Enemy
]],[[
Asphyxia's Wrath
Feathered Arrow Quiver
Requires Level 20
Implicits: 1
(20-30)% increased Arrow Speed
Grants level 5 Frostbite Skill
(8-12)% increased Attack Speed
+(30-40)% to Cold Resistance
(30-40)% increased Chill Duration on Enemies
Gain 20% of Physical Damage as Extra Cold Damage
(7-10)% chance to Freeze
Hexes on Slain Enemies are transferred to a nearby Enemy
]],[[
Blackgleam
Fire Arrow Quiver
Variant: Pre 2.0.0
Variant: Pre 3.17.0
Requires Level 22
Implicits: 1
3 to 5 Added Fire Damage with Bow Attacks
10% increased Attack Speed
+(80-100) to Evasion Rating
+(10-30) to maximum Mana
{variant:1}(30-50)% of Physical Damage Converted to Fire Damage
{variant:2}50% of Physical Damage Converted to Fire Damage
Adds 5 to 10 Fire Damage to Attacks with Bows
]],[[
Blackgleam
Blazing Arrow Quiver
Requires Level 45
Implicits: 1
(12-15) to (24-27) Added Fire Damage with Bow Attacks
10% increased Attack Speed
+(80-100) to Evasion Rating
+(10-30) to maximum Mana
50% of Physical Damage Converted to Fire Damage
Adds 5 to 10 Fire Damage to Attacks with Bows
]],[[
The Signal Fire
Fire Arrow Quiver
Variant: Pre 3.14.0
Variant: Pre 3.17.0
Source: Drops from any endgame map boss
Requires Level 24
Implicits: 1
3 to 5 Added Fire Damage with Bow Attacks
10% increased Attack Speed
+(80-100) to Evasion Rating
+(10-30) to maximum Mana
{variant:1}Gain (25-35)% of Physical Damage as Extra Fire Damage
{variant:2}Gain (25-35)% of Physical Attack Damage as Extra Fire Damage
50% of Physical Damage Converted to Fire Damage
Adds 5 to 10 Fire Damage to Attacks with Bows
]],[[
The Signal Fire
Blazing Arrow Quiver
Source: Drops from any endgame map boss
Requires Level 45
Implicits: 1
(12-15) to (24-27) Added Fire Damage with Bow Attacks
10% increased Attack Speed
+(80-100) to Evasion Rating
+(10-30) to maximum Mana
Gain (25-35)% of Physical Attack Damage as Extra Fire Damage
50% of Physical Damage Converted to Fire Damage
Adds 5 to 10 Fire Damage to Attacks with Bows
]],[[
Craghead
Serrated Arrow Quiver
Variant: Pre 3.17.0
Variant: Current
Requires Level 5
Implicits: 1
1 to 4 Added Physical Damage with Bow Attacks
(20-25)% reduced Enemy Stun Threshold
25% reduced Projectile Speed
{variant:1}(60-80)% increased Stun Duration on Enemies
{variant:2}(140-200)% increased Stun Duration on Enemies
Adds 6 to 10 Physical Damage to Attacks with Bows
]],[[
Cragfall
Serrated Arrow Quiver
Source: No longer obtainable
Requires Level 5
Implicits: 1
1 to 4 Added Physical Damage with Bow Attacks
(20-25)% reduced Enemy Stun Threshold
25% reduced Projectile Speed
(60-80)% increased Stun Duration on Enemies
Adds 6 to 10 Physical Damage to Attacks with Bows
50% chance to double Stun Duration
]],[[
Drillneck
Penetrating Arrow Quiver
Requires Level 36
Implicits: 1
Arrows Pierce an additional Target
(8-12)% increased Attack Speed
+350 to Evasion Rating
+(40-50) to maximum Life
Adds (10-14) to (19-24) Physical Damage to Attacks with Bows
Arrows deal 50% increased Damage with Hits and Ailments to Targets they Pierce
]],[[
The Fracturing Spinner
Blunt Arrow Quiver
League: Harbinger
Upgrade: Upgrades to unique{The Shattered Divinity} via currency{Fragmentation Scroll}
Requires Level 60
Implicits: 1
(7-9) to (13-16) Added Physical Damage with Bow Attacks
Grants Summon Harbinger of Directions Skill
+(30-50) to Strength and Dexterity
Adds (19-22) to (30-35) Fire Damage to Spells and Attacks
Adds (19-22) to (30-35) Cold Damage to Spells and Attacks
+(15-25)% to Fire and Cold Resistances
]],[[
The Shattered Divinity
Blunt Arrow Quiver
League: Harvest
Source: Upgraded from unique{The Fracturing Spinner} via currency{Fragmentation Scroll}
Requires Level 60
Implicits: 1
(7-9) to (13-16) Added Physical Damage with Bow Attacks
Grants Summon Greater Harbinger of Directions Skill
+(30-50) to Strength and Dexterity
Adds (19-22) to (30-35) Fire Damage to Spells and Attacks
Adds (19-22) to (30-35) Cold Damage to Spells and Attacks
+(15-25)% to Fire and Cold Resistances
]],[[
Hyrri's Bite
Sharktooth Arrow Quiver
Variant: Pre 2.6.0
Variant: Current
Requires Level 14
Implicits: 1
+(6-8) Life gained for each Enemy hit by your Attacks
+(15-25) to Strength
+(35-45) to Dexterity
+(15-25) to Intelligence
{variant:2}Adds 10 to 20 Cold Damage to Attacks
(7-10)% increased Attack Speed
+(2-3) Life gained for each Enemy hit by your Attacks
10% increased Area of Effect of Area Skills
]],[[
Hyrri's Demise
Sharktooth Arrow Quiver
Source: Drops from any endgame map boss
Requires Level 45
Implicits: 1
+(6-8) Life gained for each Enemy hit by your Attacks
+(15-30) to all Attributes
(7-10)% increased Attack Speed
+(2-3) Life gained for each Enemy hit by your Attacks
10% increased Area of Effect
Adds 1 to 2 Cold Damage to Attacks per 10 Dexterity
Adds 1 to 2 Fire Damage to Attacks per 10 Strength
Adds 0 to 3 Lightning Damage to Attacks per 10 Intelligence
]],[[
Maloney's Mechanism
Ornate Quiver
Requires Level 45
Implicits: 1
Has 1 Socket
Has 2 Sockets
Trigger a Socketed Bow Skill when you Attack with a Bow, with a 1 second Cooldown
(7-12)% increased Attack Speed
+(50-70) to maximum Life
5% chance to Blind Enemies on Hit with Attacks
]],[[
Replica Maloney's Mechanism
Ornate Quiver
League: Heist
Requires Level 45
Implicits: 1
Has 1 Socket
Has 2 Sockets
Trigger a Socketed Bow Skill when you Cast a Spell while wielding a Bow
(7-12)% increased Cast Speed
+(50-70) to maximum Life
5% chance to Blind Enemies on Hit with Attacks
]],[[
Maloney's Nightfall
Blunt Arrow Quiver
Variant: Pre 2.6.0
Variant: Pre 3.17.0
Requires Level 55
Implicits: 1
(7-9) to (13-16) Added Physical Damage with Bow Attacks
{variant:1}(8-10)% increased Attack Speed
{variant:2}10% increased Attack Speed
+(50-70) to maximum Life
+(12-16)% to Chaos Resistance
{variant:1}Adds (5-7) to (8-10) Physical Damage to Attacks with Bows
{variant:2}Adds (8-10) to (14-16) Physical Damage to Attacks with Bows
{variant:1}10% chance to create a Smoke Cloud when Hit
{variant:2}25% chance to create a Smoke Cloud when Hit
{variant:1}(20-40)% increased Damage with Hits and Ailments against Blinded Enemies
{variant:2}(40-60)% increased Damage with Hits and Ailments against Blinded Enemies
]],[[
Maloney's Nightfall
Vile Arrow Quiver
Requires Level 55
Implicits: 1
Gain (10-15)% of Physical Damage as Extra Chaos Damage
10% increased Attack Speed
+(50-70) to maximum Life
+(12-16)% to Chaos Resistance
Adds (8-10) to (14-16) Physical Damage to Attacks with Bows
25% chance to create a Smoke Cloud when Hit
(40-60)% increased Damage with Hits and Ailments against Blinded Enemies
]],[[
Rearguard
Broadhead Arrow Quiver
Variant: Pre 3.17.0
Requires Level 49
Implicits: 1
(8-10)% increased Attack Speed
+(400-450) to Armour
(20-30)% increased Projectile Speed
50% increased Stun Recovery
(15-20)% increased Projectile Damage
(20-24)% Chance to Block
(12-15)% Chance to Block Spells
]],[[
Rearguard
Blunt Arrow Quiver
Requires Level 31
Implicits: 1
(7-9) to (13-16) Added Physical Damage with Bow Attacks
+(400-450) to Armour
(20-30)% increased Projectile Speed
50% increased Stun Recovery
(15-20)% increased Projectile Damage
(20-24)% Chance to Block
(12-15)% Chance to Block Spells
]],[[
Rigwald's Quills
Two-Point Arrow Quiver
Variant: Pre 3.14.0
Variant: Current
League: Talisman Standard, Talisman Hardcore
Source: Drops from unique{Rigwald, The Wolven King} (Level 70+)
Requires Level 56
Implicits: 1
(20-30)% increased Global Accuracy Rating
-10% to Fire Resistance
+(20-30)% to Lightning Resistance
+7 Life gained for each Enemy hit by your Attacks
20% reduced Projectile Speed
(30-50)% increased Projectile Damage
{variant:1}Projectiles Fork
{variant:2}Arrows Fork
]],[[
Saemus' Gift
Spike-Point Arrow Quiver
Requires Level 45
Implicits: 1
(20-30)% increased Critical Strike Chance with Bows
+(30-40) to Dexterity
(8-12)% increased Cast Speed
+(30-60) to maximum Life
+(20-40)% to Lightning Resistance
20% chance to Avoid being Stunned
1% increased Lightning Damage per 10 Intelligence
]],[[
Scorpion's Call
Broadhead Arrow Quiver
Variant: Pre 3.17.0
League: Harvest
Requires Level 57
Implicits: 1
(8-10)% increased Attack Speed
+(20-40) to Dexterity
(150-200) Life Regenerated per Second while in Blood Stance
(40-60)% increased Projectile Damage while in Blood Stance
+(700-1000) to Evasion Rating while in Sand Stance
(20-30)% increased Area of Effect while in Sand Stance
(20-30)% increased Attack Speed if you've changed Stance Recently
]],[[
Scorpion's Call
Heavy Arrow Quiver
League: Harvest
Requires Level 61
Implicits: 1
(12-16) to (24-27) Added Physical Damage with Bow Attacks
+(20-40) to Dexterity
(150-200) Life Regenerated per Second while in Blood Stance
(40-60)% increased Projectile Damage while in Blood Stance
+(700-1000) to Evasion Rating while in Sand Stance
(20-30)% increased Area of Effect while in Sand Stance
(20-30)% increased Attack Speed if you've changed Stance Recently
]],[[
Skirmish
Two-Point Arrow Quiver
Requires Level 36
Implicits: 1
(20-30)% increased Global Accuracy Rating
+(15-25) to Intelligence
+(30-50) to maximum Mana
(20-30)% increased Mana Regeneration Rate
0.2% of Physical Attack Damage Leeched as Mana
Attack skills can have 1 additional Totem Summoned at a time
]],[[
Steelworm
Broadhead Arrow Quiver
Variant: Pre 3.17.0
Requires Level 52
Implicits: 1
(8-10)% increased Attack Speed
Grants Call of Steel
(30-60)% increased Evasion Rating and Armour
Deal no Non-Physical Damage
Attacks that Fire Projectiles Consume up to 1 additional Steel Shard
Skills Fire 3 additional Projectiles for 4 seconds after you consume a total of 12 Steel Shards
]],[[
Steelworm
Feathered Arrow Quiver
Requires Level 52
Implicits: 1
(20-30)% increased Arrow Speed
Grants Call of Steel
(30-60)% increased Evasion Rating and Armour
Deal no Non-Physical Damage
Attacks that Fire Projectiles Consume up to 1 additional Steel Shard
Skills Fire 3 additional Projectiles for 4 seconds after you consume a total of 12 Steel Shards
]],[[
Soul Strike
Spike-Point Arrow Quiver
Variant: Pre 2.5.0
Variant: Current
Requires Level 64
Implicits: 1
(20-30)% increased Critical Strike Chance with Bows
+30 to Dexterity
Adds (13-18) to (26-32) Chaos Damage to Attacks
(8-12)% increased Attack Speed
+(100-120) to maximum Energy Shield
40% reduced Energy Shield Recharge Rate
{variant:1}150% faster start of Energy Shield Recharge
{variant:2}80% faster start of Energy Shield Recharge
]],[[
Replica Soul Strike
Spike-Point Arrow Quiver
League: Heist
Requires Level 64
Implicits: 1
(20-30)% increased Critical Strike Chance with Bows
+30 to Dexterity
Adds (13-18) to (26-32) Physical Damage to Attacks
(8-12)% increased Attack Speed
+(60-80) to maximum Life
80% reduced Maximum Recovery per Life Leech
40% increased Maximum total Recovery per second from Life Leech
]],[[
Voidfletcher
Penetrating Arrow Quiver
Variant: Pre 3.17.0
Elder
Source: Drops from unique{The Elder} (Uber)
Requires Level 68
Implicits: 1
Arrows Pierce an additional Target
Consumes a Void Charge to Trigger Level 20 Void Shot when you fire Arrows
Adds (30-40) to (80-100) Cold Damage to Attacks
+(80-120) to maximum Energy Shield
+(20-30)% to Cold Resistance
+(20-40) Mana gained on Kill
30% increased Projectile Speed
5 Maximum Void Charges
Gain a Void Charge every 0.5 seconds
Elder Item
]],[[
Voidfletcher
Primal Arrow Quiver
Elder
Source: Drops from unique{The Elder} (Uber)
Requires Level 68
Implicits: 1
(20-30)% increased Elemental Damage with Attack Skills
Consumes a Void Charge to Trigger Level 20 Void Shot when you fire Arrows
Adds (30-40) to (80-100) Cold Damage to Attacks
+(80-120) to maximum Energy Shield
+(20-30)% to Cold Resistance
+(20-40) Mana gained on Kill
30% increased Projectile Speed
5 Maximum Void Charges
Gain a Void Charge every 0.5 seconds
Elder Item
]],
}
